@@ -26,7 +26,7 @@ $.fn.listcrudrest = function(){
         list.html(html);
     }
     $(btn).on('click', function(){
-        $(form).closest('.x_content').find('.alert').remove();
+        $(form).closest('.card').find('.alert').remove();
         $.ajax({
             url: url_add, // url where to submit the request
             type : "POST", // type of action POST || GET
