@@ -18,6 +18,8 @@ from django.urls import reverse_lazy
 from django.utils import formats
 from django.utils.translation import gettext as _
 
+from djgentelella.models import ChunkedUpload
+
 
 def update_kwargs(attrs, widget, base_class='form-control '):
     if attrs is not None:
@@ -117,6 +119,21 @@ class NumberInput(Input):
         super().__init__(attrs, extraskwargs=extraskwargs)
 
 
+class FloatInput(Input):
+    input_type = 'number'
+    template_name = 'gentelella/widgets/number.html'
+
+    # min_value y max_value
+
+    def __init__(self, attrs=None, extraskwargs=True):
+        if extraskwargs:
+            attrs = update_kwargs(attrs, self.__class__.__name__)
+        if 'step' not in attrs:
+            attrs['step'] = "0.1"
+        attrs['inputmode'] = "decimal"
+        super().__init__(attrs, extraskwargs=extraskwargs)
+
+
 class EmailInput(Input):
     input_type = 'email'
     template_name = 'gentelella/widgets/email.html'
@@ -168,6 +185,22 @@ class FileInput(DJFileInput):
             attrs['data-done'] = reverse_lazy('upload_file_done')
         super().__init__(attrs)
 
+    def format_value(self, value):
+        """File input never renders a value."""
+        return
+
+    def value_from_datadict(self, data, files, name):
+        dev = None
+        token = data.get(name)
+        tmpupload = ChunkedUpload.objects.filter(upload_id=token).first()
+        if tmpupload:
+            dev = tmpupload.get_uploaded_file()
+            tmpupload.delete()
+        return dev
+
+    def value_omitted_from_data(self, data, files, name):
+        return name not in data
+
 
 class ImageRecordInput(DJFileInput):
     """
@@ -373,6 +406,9 @@ class YesNoInput(DJCheckboxInput):
         if 'rel' in attrs:
             rel = attrs.pop('rel')
             attrs['data-rel'] = ';'.join(rel)
+        if 'rel_start_hidden' in attrs:
+            rel = attrs.pop('rel_start_hidden')
+            attrs['data-relhidden'] = ';'.join(rel)
         attrs['data-shparent'] = shparent
         super().__init__(attrs)
         self.format = format or None
